#!/usr/bin/env python3

from setuptools import setup, find_packages
import sys

setup(
    name="pymiso",
    description="",
    version="0.0.1",
    author="Hannah Ward",
    author_email="hannah.ward9001@gmail.com",
    packages=find_packages(),
)
